.wy-side-nav-search{
    display: none !important;
}
.wy-nav-side .wy-side-scroll{
    background: #49392c ;
    background-size: 177px 40px;
}
.current .toctree-l1 .reference:hover{
    background:  #693F0C ;
}
.wy-menu .current .toctree-l2{
    background: #33281f;
}
.wy-side-scroll .wy-menu-vertical li.current a{
    color: #fff;
}
.current .toctree-l1 .toctree-l2 .reference:hover{
    background: rgba(39,34,28,1);
}

.wy-menu-vertical li.on a, .wy-menu-vertical li.current>a {
    color: #404040;
    padding: 0.4045em 1.618em;
    font-weight: bold;
    position: relative;
    background: #3e3125 !important;
    border: none;
    border-bottom: solid 0px #000 !important;
    border-top: solid 0px #000 !important;
    padding-left: -4px;
}
.wy-side-scroll .wy-menu-vertical a{
	color: #fff;
}
.wy-menu-vertical li.current a{
	border-right: 0px !important;
}
.wy-side-scroll .wy-menu .current .toctree-l3{
    background: rgba(52,44,36,1);
}
.wy-menu-vertical li.toctree-l2.current li.toctree-l3 > a{
	background: none !important;
}
.wy-body-for-nav{
    height: 100%;
}
#qh-header{
    position: absolute;
    z-index: 1000;
    width: 100%;
    top: 0;
    left: 0;
    height: 67px;
    line-height: 67px;
    text-align: right;
    color: #FFF;
    background: #4a4a4a url("../images/logo.png") 47px 4px no-repeat !important;
    background-size: 60px !important;
}

#qh-header .title{
    padding-left: 130px;
    float: left;
}
#qh-header .title i{
    font-style: normal;
}
#qh-header .title i:nth-child(1){
    font-size: 24px;
}
#qh-header>a{
    display: inline-block;
    height: 100%;
    margin-right: 42px;
    box-sizing: border-box;
    color: #fff;
}
#qh-header .api{
    height: calc(100% - 5px);
    border-top: solid 5px #000;
}
#qh-header~.wy-grid-for-nav{
    height: calc(100% - 67px);
    margin-top: 67px;
    z-index: 999;
    position: relative;
    overflow: hidden;
}
#qh-header~.wy-grid-for-nav .wy-nav-side,#qh-header~.wy-grid-for-nav .wy-nav-content-wrap{
    height: 100%;
    position: absolute;
    top: 0;
}
#qh-header~.wy-grid-for-nav .wy-nav-side{
    left: 0;
}
#qh-header~.wy-grid-for-nav .wy-nav-side .wy-side-scroll{
    height: 100%;
}
#qh-header~.wy-grid-for-nav .wy-nav-content-wrap{
    width: calc(100% - 300px);
    overflow-y: auto;
    right: 0;
}
.rst-content>.document .section[id]{
    margin-top: 67px;
}
.wy-side-scroll .wy-menu-vertical li.toctree-l2.current > a {
    background: #C9C9C9 none repeat scroll 0% 0%;
    padding: 0.4045em 2.427em;
    color: #ff6000;
}
.wy-menu-vertical .toctree-l1 .toctree-l2 .toctree-l3 .reference{
    background: #33281f !important;
}
.wy-menu-vertical .toctree-l1 .toctree-l2 .toctree-l3 .reference:hover{
    background: #693F0C !important;
}
.wy-menu-vertical .toctree-l1 .toctree-l2 .current .reference{
    background: #241c16 !important;
    color: #ff6000;
}
.wy-nav-content{
    max-width: 100% !important;
}
.rst-content img{
    max-width: 60% !important;
}
.wy-grid-for-nav .wy-nav-side{
    background: #49392c;
}
.wy-breadcrumbs li.wy-breadcrumbs-aside{
    display: none;
}
@media screen and (min-width: 1400px){
    .wy-nav-content-wrap {
        background: none !important;
    }
}
